@@ -42,7 +42,6 @@ plot.metagam <- function(x, term = NULL, ci = "none", legend = FALSE,
     metadat <- x$meta_models$predictions
   }
 
-
   xvars <- x$term_list[[term]]$xvars
   metadat <- metadat[, c(xvars, "estimate", "se")]
 
@@ -63,6 +62,10 @@ plot.metagam <- function(x, term = NULL, ci = "none", legend = FALSE,
       ret$model <- nms[[ind]]
       ret
     })
+
+    common_cols <- Reduce(intersect, lapply(dat, colnames))
+    dat <- lapply(dat, function(df) df[, common_cols, drop = FALSE])
+
     dat <- do.call(rbind, dat)
     dat <- dat[, c(xvars, "fit", "se.fit", "model")]
 
@@ -89,14 +92,14 @@ plot.metagam <- function(x, term = NULL, ci = "none", legend = FALSE,
   } else if(length(xvars) == 2){
     metadat <- metadat[, c(xvars, "estimate", "se")]
 
-    plot_bivariate_smooth(metadat, xvars, term)
+    plot_bivariate_smooth(metadat, xvars)
   } else {
     stop("plot.metagam currently only works for univariate or bivariate terms.")
   }
 
 }
 
-plot_bivariate_smooth <- function(metadat, xvars, term){
+plot_bivariate_smooth <- function(metadat, xvars){
 
   names(metadat)[names(metadat) %in% xvars] <- c("xxxaaa", "xxxbbb")
 
@@ -104,7 +107,6 @@ plot_bivariate_smooth <- function(metadat, xvars, term){
                                         z = .data$estimate)) +
     ggplot2::geom_raster(ggplot2::aes(fill = .data$estimate)) +
     ggplot2::geom_contour() +
-    ggplot2::labs(term) +
     ggplot2::theme_minimal() +
     ggplot2::scale_fill_distiller(palette = "RdBu", type = "div") +
     ggplot2::xlab(xvars[[1]]) +
